@@ -19,6 +19,8 @@ class Config(object):
             should_access_file (bool) - should the file be read/write?
             filename (string) - file to read/write the config - used only for testing.
         """
+        self._should_access_file = should_access_file
+
         self._filename = filename or os.path.join(
             environment.HOME_DIR, ".moz-phab-config"
         )
@@ -48,12 +50,13 @@ class Config(object):
             [patch]
             apply_to = base
             create_bookmark = True
+            create_topic = False
             always_full_stack = False
 
             [updater]
             self_last_check = 0
-            arc_last_check = 0
             self_auto_update = True
+            get_pre_releases = False
 
             [error_reporting]
             report_to_sentry = True
@@ -73,23 +76,22 @@ class Config(object):
         if should_access_file:
             self._config.read([self._filename])
 
-        self.no_ansi = self._config.getboolean("ui", "no_ansi")
-        self.safe_mode = self._config.getboolean("vcs", "safe_mode")
-        self.auto_submit = self._config.getboolean("submit", "auto_submit")
-        self.always_blocking = self._config.getboolean("submit", "always_blocking")
-        self.warn_untracked = self._config.getboolean("submit", "warn_untracked")
+        self.no_ansi = self._getboolean("ui", "no_ansi")
+        self.safe_mode = self._getboolean("vcs", "safe_mode")
+        self.auto_submit = self._getboolean("submit", "auto_submit")
+        self.always_blocking = self._getboolean("submit", "always_blocking")
+        self.warn_untracked = self._getboolean("submit", "warn_untracked")
         self.apply_patch_to = self._config.get("patch", "apply_to")
-        self.create_bookmark = self._config.getboolean("patch", "create_bookmark")
-        self.always_full_stack = self._config.getboolean("patch", "always_full_stack")
-        self.self_last_check = self._config.getint("updater", "self_last_check")
-        self.self_auto_update = self._config.getboolean("updater", "self_auto_update")
-        self.arc_last_check = self._config.getint("updater", "arc_last_check")
+        self.create_bookmark = self._getboolean("patch", "create_bookmark")
+        self.create_topic = self._getboolean("patch", "create_topic")
+        self.always_full_stack = self._getboolean("patch", "always_full_stack")
+        self.self_last_check = self._getint("updater", "self_last_check")
+        self.self_auto_update = self._getboolean("updater", "self_auto_update")
+        self.get_pre_releases = self._getboolean("updater", "get_pre_releases")
         git_remote = self._config.get("git", "remote")
         self.git_remote = git_remote.replace(" ", "").split(",") if git_remote else []
-        self.report_to_sentry = self._config.getboolean(
-            "error_reporting", "report_to_sentry"
-        )
-        self.telemetry_enabled = self._config.getboolean("telemetry", "enabled")
+        self.report_to_sentry = self._getboolean("error_reporting", "report_to_sentry")
+        self.telemetry_enabled = self._getboolean("telemetry", "enabled")
         self._git_command = self._config.get("git", "command_path")
         self.git_command = (
             [self._git_command] if self._git_command else environment.GIT_COMMAND
@@ -109,14 +111,33 @@ class Config(object):
             self._config.add_section(section)
         self._config.set(section, option, str(value))
 
+    def _getboolean(self, section, option):
+        try:
+            return self._config.getboolean(section, option)
+        except ValueError as e:
+            raise ValueError(
+                f"could not convert {section}.{option} to a boolean: {str(e)}"
+            )
+
+    def _getint(self, section, option):
+        try:
+            return self._config.getint(section, option)
+        except ValueError as e:
+            raise ValueError(
+                f"could not convert {section}.{option} to an integer: {str(e)}"
+            )
+
     def write(self):
+        if not self._should_access_file:
+            return
+
         if os.path.exists(self._filename):
             logger.debug("updating %s", self._filename)
             self._set("submit", "auto_submit", self.auto_submit)
             self._set("patch", "always_full_stack", self.always_full_stack)
             self._set("updater", "self_last_check", self.self_last_check)
-            self._set("updater", "arc_last_check", self.arc_last_check)
             self._set("updater", "self_auto_update", self.self_auto_update)
+            self._set("updater", "get_pre_releases", self.get_pre_releases)
             self._set("telemetry", "enabled", self.telemetry_enabled)
 
         else:
@@ -131,6 +152,7 @@ class Config(object):
             self._set("submit", "warn_untracked", self.warn_untracked)
             self._set("patch", "apply_to", self.apply_patch_to)
             self._set("patch", "create_bookmark", self.create_bookmark)
+            self._set("patch", "create_topic", self.create_topic)
             self._set("patch", "always_full_stack", self.always_full_stack)
             self._set("telemetry", "enabled", self.telemetry_enabled)
 
@@ -138,4 +160,8 @@ class Config(object):
             self._config.write(f)
 
 
-config = Config()
+should_access_file = True
+if os.environ.get("MOZPHAB_NO_USER_CONFIG", False):
+    should_access_file = False
+
+config = Config(should_access_file)
