@@ -11,21 +11,21 @@ CLI to support submission of a series of commits to Phabricator. .
 
 import logging
 import os
+import ssl
 import sys
 import traceback
 
 from mozphab import environment
 
-from .arcanist import install_arc_if_required
 from .args import parse_args
-from .conduit import conduit
+from .conduit import conduit, ConduitAPIError
 from .config import config
 from .detect_repository import repo_from_args
 from .exceptions import Error
 from .logger import init_logging, logger
 from .spinner import wait_message
 from .sentry import init_sentry, report_to_sentry
-from .telemetry import telemetry
+from .telemetry import telemetry, configure_telemetry
 from .updater import check_for_updates
 
 # Known Issues
@@ -58,8 +58,11 @@ def main(argv, *, is_development):
 
         logger.debug("%s (%s)", environment.MOZPHAB_NAME, environment.MOZPHAB_VERSION)
 
-        if not args.no_arc:
-            install_arc_if_required()
+        if args.fallback:
+            if len(argv) > 1:
+                logger.info(f"command {argv[1]} not found; falling back to submit")
+            else:
+                logger.info("moz-phab called without arguments; falling back to submit")
 
         # Ensure that `patch --raw ..` only outputs the patch
         if args.command == "patch" and getattr(args, "raw", False):
@@ -67,7 +70,7 @@ def main(argv, *, is_development):
             logger.setLevel(logging.ERROR)
 
         elif args.command != "self-update":
-            check_for_updates(with_arc=not args.no_arc)
+            check_for_updates()
 
         repo = None
         if args.needs_repo:
@@ -76,10 +79,19 @@ def main(argv, *, is_development):
 
             conduit.set_repo(repo)
 
-        telemetry.set_metrics(args, is_development=is_development)
+        if not is_development:
+            configure_telemetry(args)
 
         if repo is not None:
-            telemetry.set_vcs(repo)
+            try:
+                conduit.load_api_token()
+            except ConduitAPIError:
+                logger.info("No API token detected, running `install-certificate`...")
+                install = parse_args(["install-certificate"])
+                install.func(repo, install)
+                logger.info("Token installed, resuming original command")
+
+            telemetry().set_vcs(repo)
             try:
                 args.func(repo, args)
             finally:
@@ -88,11 +100,28 @@ def main(argv, *, is_development):
         else:
             args.func(args)
 
-        telemetry.metrics.mozphab.usage.command_time.stop()
-        telemetry.submit()
+        telemetry().usage.command_time.stop()
+        telemetry().submit()
 
     except KeyboardInterrupt:
         pass
+    except ssl.SSLCertVerificationError as e:
+        logger.error(e)
+
+        if e.reason == "CERTIFICATE_VERIFY_FAILED":
+            # Leave a helpful error message if the local issuer certificate
+            # can't be found.
+            logger.error(
+                "\nYour Python installation is incomplete as you lack a local issuer "
+                "certificate.\n"
+                "See the following link for steps to resolve your problem:\n"
+                "https://stackoverflow.com/questions/52805115/"
+                "certificate-verify-failed-unable-to-get-local-issuer-certificate\n"
+                "\n"
+                "If you still experience trouble please file a bug."
+            )
+
+        sys.exit(1)
     except Error as e:
         logger.error(e)
         sys.exit(1)
