@@ -6,6 +6,11 @@ import json
 import os
 import urllib.parse
 
+from typing import (
+    List,
+    Optional,
+)
+
 from mozphab import environment
 
 from .conduit import conduit, normalise_reviewer
@@ -152,6 +157,19 @@ class Repository(object):
     def amend_commit(self, commit, commits):
         """Amend commit description from `title` and `desc` fields"""
 
+    def is_descendant(self, node: str) -> bool:
+        """Return `True` if the repository revset is descendant from `node`."""
+
+    def map_callsign_to_unified_head(self, callsign: str) -> Optional[str]:
+        """Return the expected VCS identifier for the given callsign.
+
+        Returns a VCS identifier that corresponds to the given Phabricator repository
+        callsign. Confirms the identified head exists in the repository.
+        """
+
+    def uplift_commits(self, dest: str, commits: List[dict]) -> List[dict]:
+        """Uplift the repo's revset onto `dest` and returns the refreshed `commits`."""
+
     def rebase_commit(self, source_commit, dest_commit):
         """Rebase source onto destination."""
 
@@ -367,3 +385,6 @@ class Repository(object):
     def get_public_node(self, node):
         """Hashtag in a remote VCS."""
         return node
+
+    def validate_email(self):
+        """Validate a user's configured email address."""
